/hg/gfx-test: * src/org/gfxtest/testsuites/ClippingPathByEllipse...

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Wed May 16 05:14:58 PDT 2012


changeset acbba33950fb in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=acbba33950fb
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Wed May 16 14:17:39 2012 +0200

	* src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java:
	Added new tests to this test suite.


diffstat:

 ChangeLog                                                  |    5 +
 src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java |  142 ++++++++++++-
 2 files changed, 146 insertions(+), 1 deletions(-)

diffs (185 lines):

diff -r fe2ac03939d3 -r acbba33950fb ChangeLog
--- a/ChangeLog	Tue May 15 11:48:01 2012 +0200
+++ b/ChangeLog	Wed May 16 14:17:39 2012 +0200
@@ -1,3 +1,8 @@
+2012-05-16  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java:
+	Added new tests to this test suite.
+
 2012-05-15  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/ClippingPathByRoundRectangleShape.java:
diff -r fe2ac03939d3 -r acbba33950fb src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java
--- a/src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java	Tue May 15 11:48:01 2012 +0200
+++ b/src/org/gfxtest/testsuites/ClippingPathByEllipseShape.java	Wed May 16 14:17:39 2012 +0200
@@ -74,6 +74,8 @@
 @Zoom(1)
 public class ClippingPathByEllipseShape extends GfxTest
 {
+    private static final float[] DOTTED_PATTERN = new float[] {1,40};
+
     /**
      * Prepare canvas for the rendering.
      *
@@ -650,7 +652,7 @@
      */
     public TestResult testClipLinePathByEllipseShapeDashedStrokePaint(TestImage image, Graphics2D graphics2d)
     {
         // render clip ellipse
         CommonClippingOperations.renderClipEllipse(image, graphics2d);
         // set dashed pattern
         CommonRenderingStyles.setDashedStrokePattern(graphics2d);
@@ -661,6 +663,72 @@
     }
 
     /**
+     * Check if cubic path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with default stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipCubicPathByEllipseShapeDashedStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawCubicPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Check if quadratic path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with default stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipQuadraticPathByEllipseShapeDashedStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawQuadraticPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Check if closed crossed path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with default stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipCrossedClosedPathByEllipseShapeDashedStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawCrossedPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
      * Check if closed path could be clipped by an ellipse shape. Path is
      * rendered using stroke paint with default stroke width.
      * 
@@ -707,6 +775,78 @@
     }
 
     /**
+     * Check if cubic path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with thick stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipCubicPathByEllipseShapeDashedThickStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set stroke width
+        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawCubicPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Check if quadratic path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with thick stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipQuadraticPathByEllipseShapeDashedThickStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set stroke width
+        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawQuadraticPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Check if closed crossed path could be clipped by an ellipse shape. Path is
+     * rendered using stroke paint with thick stroke width.
+     * 
+     * @param image
+     *            work image
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testClipCrossedClosedPathByEllipseShapeDashedThickStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // render clip ellipse shape
+        CommonClippingOperations.renderClipEllipse(image, graphics2d);
+        // set stroke width
+        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
+        // set dashed pattern
+        CommonRenderingStyles.setDashedStrokePattern(graphics2d);
+        // set clip region and draw the path
+        drawCrossedPathClippedByEllipseShape(image, graphics2d);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
      * Check if closed path could be clipped by an ellipse shape. Path is
      * rendered using stroke paint with thick stroke width.
      * 
@@ -650,7 +652,7 @@
     public TestResult testClipLinePathByEllipseShapeDashedStrokePaint(TestImage image, Graphics2D graphics2d)
     {
-        // render clip ellipse
+        // render clip ellipse shape
         CommonClippingOperations.renderClipEllipse(image, graphics2d);
         // set dashed pattern



More information about the distro-pkg-dev mailing list